Extension types.
Structs
- Bool8
canonical_extension_types - The extension type for
8-bit Boolean. - Fixed
Shape Tensor canonical_extension_types - The extension type for fixed shape tensor.
- Fixed
Shape Tensor Metadata canonical_extension_types - Extension type metadata for
FixedShapeTensor. - Json
canonical_extension_types - The extension type for
JSON. - Json
Metadata canonical_extension_types - Extension type metadata for
Json. - Opaque
canonical_extension_types - The extension type for
Opaque. - Opaque
Metadata canonical_extension_types - Extension type metadata for
Opaque. - Timestamp
With Offset canonical_extension_types - The extension type for
TimestampWithOffset. - Uuid
canonical_extension_types - The extension type for
UUID. - Variable
Shape Tensor canonical_extension_types - The extension type for
VariableShapeTensor. - Variable
Shape Tensor Metadata canonical_extension_types - Extension type metadata for
VariableShapeTensor.
Enums
- Canonical
Extension Type canonical_extension_types - Canonical extension types.
Constants
- EXTENSION_
TYPE_ METADATA_ KEY - The metadata key for a serialized representation of the
ExtensionTypenecessary to reconstruct the custom type. - EXTENSION_
TYPE_ NAME_ KEY - The metadata key for the string name identifying an
ExtensionType.
Traits
- Extension
Type - Extension types.